@@ -13,11 +13,6 @@ my $location = join(' ', @ARGV) || die "Usage: $0 \$location_string";
 # Custom useragent identifier.
 my $ua = LWP::UserAgent->new(agent => 'My Geocoder');
 
-# Allow compressed replies.
-if (eval "use Compress::Zlib") {
-    $ua->default_headers(accept_encoding => 'gzip,deflate');
-}
-
 # Load any proxy settings from environment variables.
 $ua->env_proxy;
 
