@@ -9,7 +9,7 @@ use JSON;
 use LWP::UserAgent;
 use URI;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 $VERSION = eval $VERSION;
 
 sub new {
@@ -71,24 +71,9 @@ sub _geocode_rest {
         %params,
     );
 
-    my $res = $self->{response} = $self->ua->get($uri);
-    return unless $res->is_success;
-
-    # Change the content type of the response from 'application/json' so
-    # HTTP::Message will decode the character encoding.
-    $res->content_type('text/plain');
-
-    my $content = $res->decoded_content;
-    return unless $content;
-
-    my $data = eval { from_json($content) };
-    return unless $data;
-
-    my @results = @{ $data->{resourceSets}[0]{resources} || [] };
-    return wantarray ? @results : $results[0];
+    return $self->_rest_request($uri);
 }
 
-
 # Support AJAX API for backwards compatibility.
 
 sub _geocode_ajax {
@@ -137,6 +122,54 @@ sub _geocode_ajax {
     return wantarray ? @results : $results[0];
 }
 
+sub reverse_geocode {
+    my ($self, @params) = @_;
+    my %params = (@params % 2) ? (latlng => @params) : @params;
+
+    $_ = Encode::encode('utf-8', $_) for values %params;
+
+    # Maintain api compatibility with other geocoders.
+    my ($lat, $lon);
+    if (my $latlon = delete $params{latlng}) {
+        ($lat, $lon) = split '\s*,\s*', $latlon;
+    }
+    else {
+        $lat = delete $params{lat};
+        ($lon) = grep defined, delete @params{qw(lon lng long)};
+    }
+    return unless 2 == grep defined, $lat, $lon;
+
+    my $uri = URI->new("http://dev.virtualearth.net/REST/v1/Locations/$lat,$lon");
+    $uri->scheme('https') if $self->{https};
+    $uri->query_form(
+        key => $self->{key},
+        %params,
+    );
+
+    return $self->_rest_request($uri);
+}
+
+sub _rest_request {
+    my ($self, $uri) = @_;
+    return unless $uri;
+
+    my $res = $self->{response} = $self->ua->get($uri);
+    return unless $res->is_success;
+
+    # Change the content type of the response from 'application/json' so
+    # HTTP::Message will decode the character encoding.
+    $res->content_type('text/plain');
+
+    my $content = $res->decoded_content;
+    return unless $content;
+
+    my $data = eval { from_json($content) };
+    return unless $data;
+
+    my @results = @{ $data->{resourceSets}[0]{resources} || [] };
+    return wantarray ? @results : $results[0];
+}
+
 
 1;
 
@@ -225,6 +258,13 @@ Each location result is a hashref; a typical example looks like:
         },
     }
 
+=head2 reverse_geocode
+
+    $location = $geocoder->reverse_geocode(lat => $lat, lon => $lon)
+    $location = $geocoder->reverse_geocode(latlng => "$lat,$lon")
+
+Returns a location result for the given lat/lon pair.
+
 =head2 response
 
     $response = $geocoder->response()
@@ -294,7 +334,7 @@ L<http://search.cpan.org/dist/Geo-Coder-Bing/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2014 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2009-2015 gray <gray at cpan.org>, all rights reserved.
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
